import "core-js/modules/es6.number.parse-float.js";
import "core-js/modules/es6.number.constructor.js";
import "core-js/modules/es6.number.parse-int.js";
Number.parseFloat("3.14");
Number.parseInt("10");
