import _ArrayFrom from "array.from";
import _ArrayOf from "array.of";
import _DateNow from "date/Date.now";
import _MathAcosh from "math.acosh";
import _MathAtanh from "math.atanh";
import _MathCbrt from "math.cbrt";
import _MathClz from "math.clz32";
import _MathFround from "math.fround";
import _MathLog1p from "math.log1p";
import _MathSign from "math.sign";
import _NumberIsFinite from "number.isfinite";
import _NumberIsInteger from "number.isinteger";
import _NumberIsNaN from "number.isnan";
import _NumberIsSafeInteger from "number.issafeinteger";
import _NumberParseFloat from "number.parsefloat";
import _NumberParseInt from "number.parseint";
import _ObjectAssign from "object.assign";
import _ObjectDefineProperties from "object.defineproperties";
import _ObjectEntries from "object.entries";
import _ObjectFromEntries from "object.fromentries";
import _ObjectGetOwnPropertyDescriptors from "object.getownpropertydescriptors";
import _ObjectGetPrototypeOf from "object.getprototypeof";
import _ObjectIs from "object-is";
import _ObjectValues from "object.values";
import _ReflectApply from "reflect.apply";
import _ReflectGetPrototypeOf from "reflect.getprototypeof";
import _ReflectOwnKeys from "reflect.ownkeys";
import _StringFromCodePoint from "string.fromcodepoint";
import _StringRaw from "string.raw";
_ArrayFrom;
Array.isArray;
_ArrayOf;
_DateNow;
JSON.stringify;
Math.DEG_PER_RAD;
Math.RAD_PER_DEG;
_MathAcosh;
Math.asinh;
_MathAtanh;
_MathCbrt;
Math.clamp;
_MathClz;
Math.cosh;
Math.degrees;
Math.expm1;
_MathFround;
Math.fscale;
Math.hypot;
Math.iaddh;
Math.imul;
Math.imulh;
Math.isubh;
Math.log10;
_MathLog1p;
Math.log2;
Math.radians;
Math.scale;
Math.seededPRNG;
_MathSign;
Math.signbit;
Math.sinh;
Math.tanh;
Math.trunc;
Math.umulh;
Number.EPSILON;
Number.MAX_SAFE_INTEGER;
Number.MIN_SAFE_INTEGER;
Number.fromString;
_NumberIsFinite;
_NumberIsInteger;
_NumberIsNaN;
_NumberIsSafeInteger;
_NumberParseFloat;
_NumberParseInt;
_ObjectAssign;
Object.create;
_ObjectDefineProperties;
Object.defineProperty;
_ObjectEntries;
Object.freeze;
_ObjectFromEntries;
Object.getOwnPropertyDescriptor;
_ObjectGetOwnPropertyDescriptors;
Object.getOwnPropertyNames;
Object.getOwnPropertySymbols;
_ObjectGetPrototypeOf;
Object.isExtensible;
Object.isFrozen;
Object.isSealed;
_ObjectIs;
Object.keys;
Object.preventExtensions;
Object.seal;
Object.setPrototypeOf;
_ObjectValues;
_ReflectApply;
Reflect.construct;
Reflect.defineMetadata;
Reflect.defineProperty;
Reflect.deleteMetadata;
Reflect.deleteProperty;
Reflect.getMetadata;
Reflect.getMetadataKeys;
Reflect.getOwnMetadata;
Reflect.getOwnMetadataKeys;
Reflect.getOwnPropertyDescriptor;
_ReflectGetPrototypeOf;
Reflect.get;
Reflect.has;
Reflect.hasMetadata;
Reflect.hasOwnMetadata;
Reflect.isExtensible;
Reflect.metadata;
_ReflectOwnKeys;
Reflect.preventExtensions;
Reflect.set;
Reflect.setPrototypeOf;
_StringFromCodePoint;
_StringRaw;
Symbol.asyncIterator;
Symbol.dispose;
Symbol.for;
Symbol.hasInstance;
Symbol.isConcatSpreadable;
Symbol.iterator;
Symbol.keyFor;
Symbol.match;
Symbol.observable;
Symbol.patternMatch;
Symbol.replace;
Symbol.search;
Symbol.species;
Symbol.split;
Symbol.toPrimitive;
Symbol.toStringTag;
Symbol.unscopables;
Foo.bar;
Array.something;
Date.something;
JSON.parse;
Math.pow;
Symbol.something;
