import _Array$from from "core-js-pure/stable/array/from.js";
import _Map from "core-js-pure/stable/map/index.js";
import _Promise from "core-js-pure/stable/promise/index.js";
import _Symbol$match from "core-js-pure/stable/symbol/match.js";
import _getIterator from "core-js-pure/features/get-iterator.js";
import _Symbol from "core-js-pure/stable/symbol/index.js";
import _queueMicrotask from "core-js-pure/stable/queue-microtask.js";
import _globalThis from "core-js-pure/features/global-this.js";
_Array$from; // static method

_Map; // built-in

new _Promise(); // new builtin

_Symbol$match; // as member expression

_getIterator(_arr); // Symbol.iterator
// no import


Array.asdf;
Array2.from;
Map2;
new Promise2();
_Symbol.asdf;
Symbol2.match;

_arr9[Symbol2.iterator]();

_arr9[_Symbol.iterator2]();

G.assign; // static method

function H(WeakMap) {
  var blah = new WeakMap();
} // shadowed


const foo = new _Promise(resolve => {
  resolve(new _Map());
});

_queueMicrotask(() => _globalThis);

Observable.from(10);
