import "core-js/modules/esnext.array.find-last.js";
import "core-js/modules/esnext.array.find-last-index.js";
import "core-js/modules/esnext.async-iterator.constructor.js";
import "core-js/modules/esnext.iterator.constructor.js";
[].findLast(fn);
[].findLastIndex(fn);
foo.indexed;
bar.with;
buz.push;
