import _regeneratorRuntime from "regenerator-runtime";

var _marked = /*#__PURE__*/_regeneratorRuntime.mark(f);

function f() {
  return _regeneratorRuntime.wrap(function f$(_context) {
    while (1) {
      switch (_context.prev = _context.next) {
        case 0:
        case "end":
          return _context.stop();
      }
    }
  }, _marked);
}
