import _StringPrototypeAnchor from "es-string-html-methods/anchor";
import _StringPrototypeBig from "es-string-html-methods/big";
import _StringPrototypeBlink from "es-string-html-methods/blink";
import _StringPrototypeBold from "es-string-html-methods/bold";
import _StringPrototypeFixed from "es-string-html-methods/fixed";
import _StringPrototypeFontcolor from "es-string-html-methods/fontcolor";
import _StringPrototypeFontsize from "es-string-html-methods/fontsize";
import _StringPrototypeItalics from "es-string-html-methods/italics";
import _StringPrototypeLink from "es-string-html-methods/link";
import _StringPrototypeSmall from "es-string-html-methods/small";
import _StringPrototypeStrike from "es-string-html-methods/strike";
import _StringPrototypeSub from "es-string-html-methods/sub";
import _StringPrototypeSup from "es-string-html-methods/sup";

_StringPrototypeAnchor("str");

_StringPrototypeBig("str");

_StringPrototypeBlink("str");

_StringPrototypeBold("str");

_StringPrototypeFixed("str");

_StringPrototypeFontcolor("str");

_StringPrototypeFontsize("str");

_StringPrototypeItalics("str");

_StringPrototypeLink("str");

_StringPrototypeSmall("str");

_StringPrototypeStrike("str");

_StringPrototypeSub("str");

_StringPrototypeSup("str");
