var _AggregateError = require("core-js-pure/features/aggregate-error.js");

var _Map = require("core-js-pure/stable/map/index.js");

var _Promise = require("core-js-pure/stable/promise/index.js");

var _Set = require("core-js-pure/stable/set/index.js");

var _Symbol = require("core-js-pure/stable/symbol/index.js");

var _URL = require("core-js-pure/stable/url/index.js");

var _URLSearchParams = require("core-js-pure/stable/url-search-params/index.js");

var _WeakMap = require("core-js-pure/stable/weak-map/index.js");

var _WeakSet = require("core-js-pure/stable/weak-set/index.js");

var _clearImmediate = require("core-js-pure/stable/clear-immediate.js");

var _globalThis = require("core-js-pure/features/global-this.js");

var _parseFloat = require("core-js-pure/stable/parse-float.js");

var _parseInt = require("core-js-pure/stable/parse-int.js");

var _queueMicrotask = require("core-js-pure/stable/queue-microtask.js");

var _setImmediate = require("core-js-pure/stable/set-immediate.js");

var _setInterval = require("core-js-pure/stable/set-interval.js");

var _setTimeout = require("core-js-pure/stable/set-timeout.js");

_AggregateError;
_Map;
Observable;
_Promise;
_Set;
_Symbol;
_URL;
_URLSearchParams;
_WeakMap;
_WeakSet;
_clearImmediate;
compositeKey;
compositeSymbol;
_globalThis;
_parseFloat;
_parseInt;
_queueMicrotask;
_setImmediate;
_setInterval;
_setTimeout;
Array;
Boolean;
Date;
Infinity;
JSON;
NaN;
Number;
Object;
clearInterval;
clearTimeout;
something;
