var _Array$from = require("core-js-pure/features/array/from.js");

var _Array$isArray = require("core-js-pure/features/array/is-array.js");

var _Array$of = require("core-js-pure/features/array/of.js");

var _Date$now = require("core-js-pure/features/date/now.js");

var _JSON$stringify = require("core-js-pure/features/json/stringify.js");

var _Math$DEG_PER_RAD = require("core-js-pure/features/math/deg-per-rad.js");

var _Math$RAD_PER_DEG = require("core-js-pure/features/math/rad-per-deg.js");

var _Math$acosh = require("core-js-pure/features/math/acosh.js");

var _Math$asinh = require("core-js-pure/features/math/asinh.js");

var _Math$atanh = require("core-js-pure/features/math/atanh.js");

var _Math$cbrt = require("core-js-pure/features/math/cbrt.js");

var _Math$clamp = require("core-js-pure/features/math/clamp.js");

var _Math$clz = require("core-js-pure/features/math/clz32.js");

var _Math$cosh = require("core-js-pure/features/math/cosh.js");

var _Math$degrees = require("core-js-pure/features/math/degrees.js");

var _Math$expm = require("core-js-pure/features/math/expm1.js");

var _Math$fround = require("core-js-pure/features/math/fround.js");

var _Math$fscale = require("core-js-pure/features/math/fscale.js");

var _Math$hypot = require("core-js-pure/features/math/hypot.js");

var _Math$iaddh = require("core-js-pure/features/math/iaddh.js");

var _Math$imul = require("core-js-pure/features/math/imul.js");

var _Math$imulh = require("core-js-pure/features/math/imulh.js");

var _Math$isubh = require("core-js-pure/features/math/isubh.js");

var _Math$log = require("core-js-pure/features/math/log10.js");

var _Math$log1p = require("core-js-pure/features/math/log1p.js");

var _Math$log2 = require("core-js-pure/features/math/log2.js");

var _Math$radians = require("core-js-pure/features/math/radians.js");

var _Math$scale = require("core-js-pure/features/math/scale.js");

var _Math$seededPRNG = require("core-js-pure/features/math/seeded-prng.js");

var _Math$sign = require("core-js-pure/features/math/sign.js");

var _Math$signbit = require("core-js-pure/features/math/signbit.js");

var _Math$sinh = require("core-js-pure/features/math/sinh.js");

var _Math$tanh = require("core-js-pure/features/math/tanh.js");

var _Math$trunc = require("core-js-pure/features/math/trunc.js");

var _Math$umulh = require("core-js-pure/features/math/umulh.js");

var _Number$EPSILON = require("core-js-pure/features/number/epsilon.js");

var _Number$MAX_SAFE_INTEGER = require("core-js-pure/features/number/max-safe-integer.js");

var _Number$MIN_SAFE_INTEGER = require("core-js-pure/features/number/min-safe-integer.js");

var _Number$fromString = require("core-js-pure/features/number/from-string.js");

var _Number$isFinite = require("core-js-pure/features/number/is-finite.js");

var _Number$isInteger = require("core-js-pure/features/number/is-integer.js");

var _Number$isNaN = require("core-js-pure/features/number/is-nan.js");

var _Number$isSafeInteger = require("core-js-pure/features/number/is-safe-integer.js");

var _Number$parseFloat = require("core-js-pure/features/number/parse-float.js");

var _Number$parseInt = require("core-js-pure/features/number/parse-int.js");

var _Object$assign = require("core-js-pure/features/object/assign.js");

var _Object$create = require("core-js-pure/features/object/create.js");

var _Object$defineProperties = require("core-js-pure/features/object/define-properties.js");

var _Object$defineProperty = require("core-js-pure/features/object/define-property.js");

var _Object$entries = require("core-js-pure/features/object/entries.js");

var _Object$freeze = require("core-js-pure/features/object/freeze.js");

var _Object$fromEntries = require("core-js-pure/features/object/from-entries.js");

var _Object$getOwnPropertyDescriptor = require("core-js-pure/features/object/get-own-property-descriptor.js");

var _Object$getOwnPropertyDescriptors = require("core-js-pure/features/object/get-own-property-descriptors.js");

var _Object$getOwnPropertyNames = require("core-js-pure/features/object/get-own-property-names.js");

var _Object$getOwnPropertySymbols = require("core-js-pure/features/object/get-own-property-symbols.js");

var _Object$getPrototypeOf = require("core-js-pure/features/object/get-prototype-of.js");

var _Object$isExtensible = require("core-js-pure/features/object/is-extensible.js");

var _Object$isFrozen = require("core-js-pure/features/object/is-frozen.js");

var _Object$isSealed = require("core-js-pure/features/object/is-sealed.js");

var _Object$is = require("core-js-pure/features/object/is.js");

var _Object$keys = require("core-js-pure/features/object/keys.js");

var _Object$preventExtensions = require("core-js-pure/features/object/prevent-extensions.js");

var _Object$seal = require("core-js-pure/features/object/seal.js");

var _Object$setPrototypeOf = require("core-js-pure/features/object/set-prototype-of.js");

var _Object$values = require("core-js-pure/features/object/values.js");

var _Reflect$apply = require("core-js-pure/features/reflect/apply.js");

var _Reflect$construct = require("core-js-pure/features/reflect/construct.js");

var _Reflect$defineMetadata = require("core-js-pure/features/reflect/define-metadata.js");

var _Reflect$defineProperty = require("core-js-pure/features/reflect/define-property.js");

var _Reflect$deleteMetadata = require("core-js-pure/features/reflect/delete-metadata.js");

var _Reflect$deleteProperty = require("core-js-pure/features/reflect/delete-property.js");

var _Reflect$getMetadata = require("core-js-pure/features/reflect/get-metadata.js");

var _Reflect$getMetadataKeys = require("core-js-pure/features/reflect/get-metadata-keys.js");

var _Reflect$getOwnMetadata = require("core-js-pure/features/reflect/get-own-metadata.js");

var _Reflect$getOwnMetadataKeys = require("core-js-pure/features/reflect/get-own-metadata-keys.js");

var _Reflect$getOwnPropertyDescriptor = require("core-js-pure/features/reflect/get-own-property-descriptor.js");

var _Reflect$getPrototypeOf = require("core-js-pure/features/reflect/get-prototype-of.js");

var _Reflect$get = require("core-js-pure/features/reflect/get.js");

var _Reflect$has = require("core-js-pure/features/reflect/has.js");

var _Reflect$hasMetadata = require("core-js-pure/features/reflect/has-metadata.js");

var _Reflect$hasOwnMetadata = require("core-js-pure/features/reflect/has-own-metadata.js");

var _Reflect$isExtensible = require("core-js-pure/features/reflect/is-extensible.js");

var _Reflect$metadata = require("core-js-pure/features/reflect/metadata.js");

var _Reflect$ownKeys = require("core-js-pure/features/reflect/own-keys.js");

var _Reflect$preventExtensions = require("core-js-pure/features/reflect/prevent-extensions.js");

var _Reflect$set = require("core-js-pure/features/reflect/set.js");

var _Reflect$setPrototypeOf = require("core-js-pure/features/reflect/set-prototype-of.js");

var _String$fromCodePoint = require("core-js-pure/features/string/from-code-point.js");

var _String$raw = require("core-js-pure/features/string/raw.js");

var _Symbol$asyncIterator = require("core-js-pure/features/symbol/async-iterator.js");

var _Symbol$dispose = require("core-js-pure/features/symbol/dispose.js");

var _Symbol$for = require("core-js-pure/features/symbol/for.js");

var _Symbol$hasInstance = require("core-js-pure/features/symbol/has-instance.js");

var _Symbol$isConcatSpreadable = require("core-js-pure/features/symbol/is-concat-spreadable.js");

var _Symbol$iterator = require("core-js-pure/features/symbol/iterator.js");

var _Symbol$keyFor = require("core-js-pure/features/symbol/key-for.js");

var _Symbol$match = require("core-js-pure/features/symbol/match.js");

var _Symbol$observable = require("core-js-pure/features/symbol/observable.js");

var _Symbol$patternMatch = require("core-js-pure/features/symbol/pattern-match.js");

var _Symbol$replace = require("core-js-pure/features/symbol/replace.js");

var _Symbol$search = require("core-js-pure/features/symbol/search.js");

var _Symbol$species = require("core-js-pure/features/symbol/species.js");

var _Symbol$split = require("core-js-pure/features/symbol/split.js");

var _Symbol$toPrimitive = require("core-js-pure/features/symbol/to-primitive.js");

var _Symbol$toStringTag = require("core-js-pure/features/symbol/to-string-tag.js");

var _Symbol$unscopables = require("core-js-pure/features/symbol/unscopables.js");

var _Symbol = require("core-js-pure/features/symbol/index.js");

_Array$from;
_Array$isArray;
_Array$of;
_Date$now;
_JSON$stringify;
_Math$DEG_PER_RAD;
_Math$RAD_PER_DEG;
_Math$acosh;
_Math$asinh;
_Math$atanh;
_Math$cbrt;
_Math$clamp;
_Math$clz;
_Math$cosh;
_Math$degrees;
_Math$expm;
_Math$fround;
_Math$fscale;
_Math$hypot;
_Math$iaddh;
_Math$imul;
_Math$imulh;
_Math$isubh;
_Math$log;
_Math$log1p;
_Math$log2;
_Math$radians;
_Math$scale;
_Math$seededPRNG;
_Math$sign;
_Math$signbit;
_Math$sinh;
_Math$tanh;
_Math$trunc;
_Math$umulh;
_Number$EPSILON;
_Number$MAX_SAFE_INTEGER;
_Number$MIN_SAFE_INTEGER;
_Number$fromString;
_Number$isFinite;
_Number$isInteger;
_Number$isNaN;
_Number$isSafeInteger;
_Number$parseFloat;
_Number$parseInt;
_Object$assign;
_Object$create;
_Object$defineProperties;
_Object$defineProperty;
_Object$entries;
_Object$freeze;
_Object$fromEntries;
_Object$getOwnPropertyDescriptor;
_Object$getOwnPropertyDescriptors;
_Object$getOwnPropertyNames;
_Object$getOwnPropertySymbols;
_Object$getPrototypeOf;
_Object$isExtensible;
_Object$isFrozen;
_Object$isSealed;
_Object$is;
_Object$keys;
_Object$preventExtensions;
_Object$seal;
_Object$setPrototypeOf;
_Object$values;
_Reflect$apply;
_Reflect$construct;
_Reflect$defineMetadata;
_Reflect$defineProperty;
_Reflect$deleteMetadata;
_Reflect$deleteProperty;
_Reflect$getMetadata;
_Reflect$getMetadataKeys;
_Reflect$getOwnMetadata;
_Reflect$getOwnMetadataKeys;
_Reflect$getOwnPropertyDescriptor;
_Reflect$getPrototypeOf;
_Reflect$get;
_Reflect$has;
_Reflect$hasMetadata;
_Reflect$hasOwnMetadata;
_Reflect$isExtensible;
_Reflect$metadata;
_Reflect$ownKeys;
_Reflect$preventExtensions;
_Reflect$set;
_Reflect$setPrototypeOf;
_String$fromCodePoint;
_String$raw;
_Symbol$asyncIterator;
_Symbol$dispose;
_Symbol$for;
_Symbol$hasInstance;
_Symbol$isConcatSpreadable;
_Symbol$iterator;
_Symbol$keyFor;
_Symbol$match;
_Symbol$observable;
_Symbol$patternMatch;
_Symbol$replace;
_Symbol$search;
_Symbol$species;
_Symbol$split;
_Symbol$toPrimitive;
_Symbol$toStringTag;
_Symbol$unscopables;
Foo.bar;
Array.something;
Date.something;
JSON.parse;
Math.pow;
_Symbol.something;
