var _str, _str2, _str3, _str4, _str5, _str6, _str7, _str8, _str9, _str10, _str11, _str12, _str13;

import _StringPrototypeAnchor from "es-string-html-methods/anchor";
import _StringPrototypeBig from "es-string-html-methods/big";
import _StringPrototypeBlink from "es-string-html-methods/blink";
import _StringPrototypeBold from "es-string-html-methods/bold";
import _StringPrototypeFixed from "es-string-html-methods/fixed";
import _StringPrototypeFontcolor from "es-string-html-methods/fontcolor";
import _StringPrototypeFontsize from "es-string-html-methods/fontsize";
import _StringPrototypeItalics from "es-string-html-methods/italics";
import _StringPrototypeLink from "es-string-html-methods/link";
import _StringPrototypeSmall from "es-string-html-methods/small";
import _StringPrototypeStrike from "es-string-html-methods/strike";
import _StringPrototypeSub from "es-string-html-methods/sub";
import _StringPrototypeSup from "es-string-html-methods/sup";
(_str = str, typeof _str === "string" ? _StringPrototypeAnchor : Function.call.bind(_str.anchor))(_str);
(_str2 = str, typeof _str2 === "string" ? _StringPrototypeBig : Function.call.bind(_str2.big))(_str2);
(_str3 = str, typeof _str3 === "string" ? _StringPrototypeBlink : Function.call.bind(_str3.blink))(_str3);
(_str4 = str, typeof _str4 === "string" ? _StringPrototypeBold : Function.call.bind(_str4.bold))(_str4);
(_str5 = str, typeof _str5 === "string" ? _StringPrototypeFixed : Function.call.bind(_str5.fixed))(_str5);
(_str6 = str, typeof _str6 === "string" ? _StringPrototypeFontcolor : Function.call.bind(_str6.fontcolor))(_str6);
(_str7 = str, typeof _str7 === "string" ? _StringPrototypeFontsize : Function.call.bind(_str7.fontsize))(_str7);
(_str8 = str, typeof _str8 === "string" ? _StringPrototypeItalics : Function.call.bind(_str8.italics))(_str8);
(_str9 = str, typeof _str9 === "string" ? _StringPrototypeLink : Function.call.bind(_str9.link))(_str9);
(_str10 = str, typeof _str10 === "string" ? _StringPrototypeSmall : Function.call.bind(_str10.small))(_str10);
(_str11 = str, typeof _str11 === "string" ? _StringPrototypeStrike : Function.call.bind(_str11.strike))(_str11);
(_str12 = str, typeof _str12 === "string" ? _StringPrototypeSub : Function.call.bind(_str12.sub))(_str12);
(_str13 = str, typeof _str13 === "string" ? _StringPrototypeSup : Function.call.bind(_str13.sup))(_str13);
