var _Map = require("core-js/library/fn/map.js");

var _Promise = require("core-js/library/fn/promise.js");

var _Set = require("core-js/library/fn/set.js");

var _Symbol = require("core-js/library/fn/symbol.js");

var _WeakMap = require("core-js/library/fn/weak-map.js");

var _WeakSet = require("core-js/library/fn/weak-set.js");

var _clearImmediate = require("core-js/library/fn/clear-immediate.js");

var _parseFloat = require("core-js/library/fn/parse-float.js");

var _parseInt = require("core-js/library/fn/parse-int.js");

var _setImmediate = require("core-js/library/fn/set-immediate.js");

AggregateError;
_Map;
Observable;
_Promise;
_Set;
_Symbol;
URL;
URLSearchParams;
_WeakMap;
_WeakSet;
_clearImmediate;
compositeKey;
compositeSymbol;
globalThis;
_parseFloat;
_parseInt;
queueMicrotask;
_setImmediate;
setInterval;
setTimeout;
Array;
Boolean;
Date;
Infinity;
JSON;
NaN;
Number;
Object;
clearInterval;
clearTimeout;
something;
