var bind, toString;

var { bind } = Function;

var { entries } = Object;

({ toString } = obj);

const [{ exec }] = something;

const { 'trim': foo } = '1';

const { foo: { filter } } = { foo: [] }

const { includes } = '';

var bar = Array;
const { from } = bar; 

const { ['o' + 'f']: fuz } = Array; 

let forEach = 'sort';
({ forEach } = zzz);
