import "regenerator-runtime/runtime.js";

var _marked = /*#__PURE__*/regeneratorRuntime.mark(a);

function a() {
  return regeneratorRuntime.wrap(function a$(_context) {
    while (1) {
      switch (_context.prev = _context.next) {
        case 0:
        case "end":
          return _context.stop();
      }
    }
  }, _marked);
}
