import "core-js/modules/es6.array.filter.js";
import "core-js/modules/es7.array.flat-map.js";
import "core-js/modules/es6.array.from.js";
import "core-js/modules/es6.array.iterator.js";
import "core-js/modules/es6.array.map.js";
import "core-js/modules/es6.array.slice.js";
import "core-js/modules/es6.array.sort.js";
import "core-js/modules/es6.array.species.js";
import "core-js/modules/es6.function.has-instance.js";
import "core-js/modules/es6.map.js";
import "core-js/modules/es6.object.assign.js";
import "core-js/modules/es7.object.define-getter.js";
import "core-js/modules/es7.object.define-setter.js";
import "core-js/modules/es7.object.entries.js";
import "core-js/modules/es7.object.get-own-property-descriptors.js";
import "core-js/modules/es7.object.lookup-getter.js";
import "core-js/modules/es7.object.lookup-setter.js";
import "core-js/modules/es6.object.to-string.js";
import "core-js/modules/es7.object.values.js";
import "core-js/modules/es6.promise.js";
import "core-js/modules/es7.promise.finally.js";
import "core-js/modules/es6.reflect.apply.js";
import "core-js/modules/es6.reflect.construct.js";
import "core-js/modules/es6.reflect.define-property.js";
import "core-js/modules/es6.reflect.delete-property.js";
import "core-js/modules/es6.reflect.get.js";
import "core-js/modules/es6.reflect.get-own-property-descriptor.js";
import "core-js/modules/es6.reflect.get-prototype-of.js";
import "core-js/modules/es6.reflect.has.js";
import "core-js/modules/es6.reflect.is-extensible.js";
import "core-js/modules/es6.reflect.own-keys.js";
import "core-js/modules/es6.reflect.prevent-extensions.js";
import "core-js/modules/es6.reflect.set.js";
import "core-js/modules/es6.reflect.set-prototype-of.js";
import "core-js/modules/es6.regexp.constructor.js";
import "core-js/modules/es6.regexp.flags.js";
import "core-js/modules/es6.regexp.match.js";
import "core-js/modules/es6.regexp.replace.js";
import "core-js/modules/es6.regexp.split.js";
import "core-js/modules/es6.regexp.search.js";
import "core-js/modules/es6.regexp.to-string.js";
import "core-js/modules/es6.set.js";
import "core-js/modules/es6.symbol.js";
import "core-js/modules/es7.symbol.async-iterator.js";
import "core-js/modules/es7.string.pad-start.js";
import "core-js/modules/es7.string.pad-end.js";
import "core-js/modules/es7.string.trim-left.js";
import "core-js/modules/es7.string.trim-right.js";
import "core-js/modules/es6.typed.array-buffer.js";
import "core-js/modules/es6.typed.int8-array.js";
import "core-js/modules/es6.typed.uint8-array.js";
import "core-js/modules/es6.typed.uint8-clamped-array.js";
import "core-js/modules/es6.typed.int16-array.js";
import "core-js/modules/es6.typed.uint16-array.js";
import "core-js/modules/es6.typed.int32-array.js";
import "core-js/modules/es6.typed.uint32-array.js";
import "core-js/modules/es6.typed.float32-array.js";
import "core-js/modules/es6.typed.float64-array.js";
import "core-js/modules/es6.weak-map.js";
import "core-js/modules/es6.weak-set.js";
import "core-js/modules/web.timers.js";
import "core-js/modules/web.immediate.js";
import "core-js/modules/web.dom.iterable.js";
1 ** 2;
