import "array.prototype.with/auto";
import "array.prototype.tosorted/auto";
import "array.prototype.toreversed/auto";
import "array.prototype.tospliced/auto";
arr.with(0, 3);
arr.toSorted();
arr.toReversed();
arr.toSpliced(1, 1, 3, 4);
