import "core-js/modules/es.object.entries.js";
import "core-js/modules/es.array.includes.js";
import "core-js/modules/es.object.values.js";
import "core-js/modules/es.array.iterator.js";
import "core-js/modules/es.object.from-entries.js";
'entries' in Object;
'includes' in [1, 2, 3];
'va' + 'lues' in Object;
var keys = 'fromEntries';
keys in Object;
