AggregateError
Map
Observable
Promise
Set
Symbol
URL
URLSearchParams
WeakMap
WeakSet
clearImmediate
compositeKey
compositeSymbol
globalThis
parseFloat
parseInt
queueMicrotask
setImmediate
setInterval
setTimeout

Array
Boolean
Date
Infinity
JSON
NaN
Number
Object
clearInterval
clearTimeout

something
