new Error(a, { cause: b });
new EvalError(a, { cause: b });
new RangeError(a, { cause: b });
new ReferenceError(a, { cause: b });
new SyntaxError(a, { cause: b });
new TypeError(a, { cause: b });
new URIError(a, { cause: b });

new AggregateError(errors, a, { cause: b });
