import _globalThis from "core-js-pure/features/global-this.js";
import _matchAllInstanceProperty from "core-js-pure/features/instance/match-all.js";
_globalThis;

_matchAllInstanceProperty(foo).call(foo, bar);
