import "core-js/modules/es7.array.flat-map.js";
import "core-js/modules/es6.array.iterator.js";
import "core-js/modules/es6.array.sort.js";
import "core-js/modules/es7.object.define-getter.js";
import "core-js/modules/es7.object.define-setter.js";
import "core-js/modules/es7.object.lookup-getter.js";
import "core-js/modules/es7.object.lookup-setter.js";
import "core-js/modules/es7.promise.finally.js";
import "core-js/modules/es7.symbol.async-iterator.js";
import "core-js/modules/es7.string.trim-left.js";
import "core-js/modules/es7.string.trim-right.js";
import "core-js/modules/web.timers.js";
import "core-js/modules/web.immediate.js";
import "core-js/modules/web.dom.iterable.js";
1 ** 2;
