require("error-cause/Error/auto");

require("error-cause/EvalError/auto");

require("error-cause/RangeError/auto");

require("error-cause/ReferenceError/auto");

require("error-cause/SyntaxError/auto");

require("error-cause/TypeError/auto");

require("error-cause/URIError/auto");

require("error-cause/AggregateError/auto");

fn(Error);
fn(EvalError);
fn(RangeError);
fn(ReferenceError);
fn(SyntaxError);
fn(TypeError);
fn(URIError);
fn(AggregateError);
