import "array.from/auto";
import "globalthis/auto";
import "es-aggregate-error/auto";
Array.from; // static method

globalThis; // built-in

new AggregateError(); // new builtin

_arr[Symbol.iterator](); // Symbol.iterator
// no import


Array.asdf;
Array2.from;
globalThis2;
new AggregateError2();
