object.at;
object.bind;
object.codePointAt;
object.codePoints;
object.concat;
object.copyWithin;
object.endsWith;
object.entries;
object.every;
object.fill;
object.filter;
object.find;
object.findIndex;
object.flags;
object.flatMap;
object.flat;
object.forEach;
object.includes;
object.indexOf;
object.keys;
object.lastIndexOf;
object.map;
object.matchAll;
object.padEnd;
object.padStart;
object.reduce;
object.reduceRight;
object.repeat;
object.replaceAll;
object.reverse;
object.slice;
object.some;
object.sort;
object.splice;
object.startsWith;
object.trim;
object.trimEnd;
object.trimLeft;
object.trimRight;
object.trimStart;
object.values;
object.something;

object.at(arg);
object.bind(arg);
object.codePointAt(arg);
object.codePoints(arg);
object.concat(arg);
object.copyWithin(arg);
object.endsWith(arg);
object.entries(arg);
object.every(arg);
object.fill(arg);
object.filter(arg);
object.find(arg);
object.findIndex(arg);
object.flags(arg);
object.flatMap(arg);
object.flat(arg);
object.forEach(arg);
object.includes(arg);
object.indexOf(arg);
object.keys(arg);
object.lastIndexOf(arg);
object.map(arg);
object.matchAll(arg);
object.padEnd(arg);
object.padStart(arg);
object.reduce(arg);
object.reduceRight(arg);
object.repeat(arg);
object.replaceAll(arg);
object.reverse(arg);
object.slice(arg);
object.some(arg);
object.sort(arg);
object.splice(arg);
object.startsWith(arg);
object.trim(arg);
object.trimEnd(arg);
object.trimLeft(arg);
object.trimRight(arg);
object.trimStart(arg);
object.values(arg);

Function.bind

object.something(arg);
