Array.from
Array.isArray
Array.of

Date.now

JSON.stringify

Math.DEG_PER_RAD
Math.RAD_PER_DEG
Math.acosh
Math.asinh
Math.atanh
Math.cbrt
Math.clamp
Math.clz32
Math.cosh
Math.degrees
Math.expm1
Math.fround
Math.fscale
Math.hypot
Math.iaddh
Math.imul
Math.imulh
Math.isubh
Math.log10
Math.log1p
Math.log2
Math.radians
Math.scale
Math.seededPRNG
Math.sign
Math.signbit
Math.sinh
Math.tanh
Math.trunc
Math.umulh

Number.EPSILON
Number.MAX_SAFE_INTEGER
Number.MIN_SAFE_INTEGER
Number.fromString
Number.isFinite
Number.isInteger
Number.isNaN
Number.isSafeInteger
Number.parseFloat
Number.parseInt

Object.assign
Object.create
Object.defineProperties
Object.defineProperty
Object.entries
Object.freeze
Object.fromEntries
Object.getOwnPropertyDescriptor
Object.getOwnPropertyDescriptors
Object.getOwnPropertyNames
Object.getOwnPropertySymbols
Object.getPrototypeOf
Object.isExtensible
Object.isFrozen
Object.isSealed
Object.is
Object.keys
Object.preventExtensions
Object.seal
Object.setPrototypeOf
Object.values

Reflect.apply
Reflect.construct
Reflect.defineMetadata
Reflect.defineProperty
Reflect.deleteMetadata
Reflect.deleteProperty
Reflect.getMetadata
Reflect.getMetadataKeys
Reflect.getOwnMetadata
Reflect.getOwnMetadataKeys
Reflect.getOwnPropertyDescriptor
Reflect.getPrototypeOf
Reflect.get
Reflect.has
Reflect.hasMetadata
Reflect.hasOwnMetadata
Reflect.isExtensible
Reflect.metadata
Reflect.ownKeys
Reflect.preventExtensions
Reflect.set
Reflect.setPrototypeOf

String.fromCodePoint
String.raw

Symbol.asyncIterator
Symbol.dispose
Symbol.for
Symbol.hasInstance
Symbol.isConcatSpreadable
Symbol.iterator
Symbol.keyFor
Symbol.match
Symbol.observable
Symbol.patternMatch
Symbol.replace
Symbol.search
Symbol.species
Symbol.split
Symbol.toPrimitive
Symbol.toStringTag
Symbol.unscopables

Foo.bar
Array.something
Date.something
JSON.parse
Math.pow

Symbol.something
