Array.from; // static method
globalThis; // built-in
new AggregateError(); // new builtin
_arr[Symbol.iterator](); // Symbol.iterator

// no import
Array.asdf;
Array2.from;
globalThis2;
new AggregateError2();
