import "core-js/modules/es.object.entries.js";
import "core-js/modules/es.array.from.js";
import "core-js/modules/es.string.iterator.js";
import "core-js/modules/es.string.includes.js";
!function (foo, {
  entries
}) {}({}, Object);
new function (foo, {
  from
}) {}({}, Array);

(({
  includes
}) => {})('42');
