Math.acosh;

Math.asinh;

Math.atanh;

Math.cbrt;

Math.clz32;

Math.cosh;

Math.expm1;

Math.fround;

Math.hypot;

Math.imul;

Math.log10;

Math.log1p;

Math.log2;

Math.sign;

Math.sinh;

Math.tanh;

Math.trunc;
