import "es-string-html-methods/anchor/auto";
import "es-string-html-methods/big/auto";
import "es-string-html-methods/blink/auto";
import "es-string-html-methods/bold/auto";
import "es-string-html-methods/fixed/auto";
import "es-string-html-methods/fontcolor/auto";
import "es-string-html-methods/fontsize/auto";
import "es-string-html-methods/italics/auto";
import "es-string-html-methods/link/auto";
import "es-string-html-methods/small/auto";
import "es-string-html-methods/strike/auto";
import "es-string-html-methods/sub/auto";
import "es-string-html-methods/sup/auto";
str.anchor();
str.big();
str.blink();
str.bold();
str.fixed();
str.fontcolor();
str.fontsize();
str.italics();
str.link();
str.small();
str.strike();
str.sub();
str.sup();
