import "core-js/modules/es.array.iterator.js";
import "core-js/modules/es.object.to-string.js";
import "core-js/modules/es.regexp.exec.js";
import "core-js/modules/es.string.replace.js";
import "core-js/modules/es.string.includes.js";
import "core-js/modules/es.regexp.flags.js";
import "core-js/modules/es.object.define-getter.js";
import "core-js/modules/es.function.bind.js";
var a = [];
a.values();
''.replace();
''.includes();
/./gi.flags;
''.indexOf();

a.__defineGetter__('foo', () => 42);

a.trim;
Function.bind;
