var _context, _context2;

import _findLastInstanceProperty from "core-js-pure/features/instance/find-last.js";
import _findLastIndexInstanceProperty from "core-js-pure/features/instance/find-last-index.js";

_findLastInstanceProperty(_context = []).call(_context, fn);

_findLastIndexInstanceProperty(_context2 = []).call(_context2, fn);

foo.indexed;
bar.with;
buz.push;
