var _Math$acosh = require("core-js/library/fn/math/acosh.js");

var _Math$asinh = require("core-js/library/fn/math/asinh.js");

var _Math$atanh = require("core-js/library/fn/math/atanh.js");

var _Math$cbrt = require("core-js/library/fn/math/cbrt.js");

var _Math$clz = require("core-js/library/fn/math/clz32.js");

var _Math$cosh = require("core-js/library/fn/math/cosh.js");

var _Math$expm = require("core-js/library/fn/math/expm1.js");

var _Math$fround = require("core-js/library/fn/math/fround.js");

var _Math$hypot = require("core-js/library/fn/math/hypot.js");

var _Math$imul = require("core-js/library/fn/math/imul.js");

var _Math$log = require("core-js/library/fn/math/log10.js");

var _Math$log1p = require("core-js/library/fn/math/log1p.js");

var _Math$log2 = require("core-js/library/fn/math/log2.js");

var _Math$sign = require("core-js/library/fn/math/sign.js");

var _Math$sinh = require("core-js/library/fn/math/sinh.js");

var _Math$tanh = require("core-js/library/fn/math/tanh.js");

var _Math$trunc = require("core-js/library/fn/math/trunc.js");

_Math$acosh;
_Math$asinh;
_Math$atanh;
_Math$cbrt;
_Math$clz;
_Math$cosh;
_Math$expm;
_Math$fround;
_Math$hypot;
_Math$imul;
_Math$log;
_Math$log1p;
_Math$log2;
_Math$sign;
_Math$sinh;
_Math$tanh;
_Math$trunc;
