require("es-aggregate-error/auto");

new Error();
new EvalError();
new RangeError();
new ReferenceError();
new SyntaxError();
new TypeError();
new URIError();
new Error(a);
new EvalError(a);
new RangeError(a);
new ReferenceError(a);
new SyntaxError(a);
new TypeError(a);
new URIError(a);
new AggregateError();
new AggregateError(errors);
new AggregateError(errors, a);
