import "array.prototype.values/auto";
import "array-includes/auto";
import "string.prototype.includes/auto";
import "regexp.prototype.flags/auto";
import "array.prototype.indexof/auto";
import "string.prototype.trim/auto";
var a = [];
a.values();
''.replace();
''.includes();
/./gi.flags;
''.indexOf();
a.trim;
