var _Promise = require("core-js/library/fn/promise.js");

var _Symbol = require("core-js/library/fn/symbol.js");

var _Map = require("core-js/library/fn/map.js");

obj.constructor === Object;
obj.constructor === _Promise;

_Symbol();

_Symbol("test");

new _Map();
