import "core-js/modules/es.object.keys.js";
import "core-js/modules/es.symbol.js";
import "core-js/modules/es.object.assign.js";
import "core-js/modules/es.object.define-property.js";
Object.keys(foo);
const getOwnPropertySymbols = Object.getOwnPropertySymbols;
const {
  assign
} = Object;
'defineProperty' in Object;
