import "array-includes/auto";
import "string.prototype.includes/auto";
import "array.prototype.find/auto";
var arrayInstance = [];
var inclidesStr = "includes";
var findStr = "find"; // Allow instance methods be assigned to variables.

arrayInstance[inclidesStr](); // include

externalVar[findStr]; // include
