import 'core-js/es/map/index.js';
import 'core-js/es/set/index';
import 'core-js/es/array/from.js';
import 'core-js/es/promise/';
import 'cOrE-jS/eS/SymBOL/iTERator';
import 'core-js\\es\\symbol\\async-iterator';
import 'foo/index.js';
