var arrayInstance = [];
var inclidesStr = "includes";
var findStr = "find";

// Allow instance methods be assigned to variables.
arrayInstance[inclidesStr](); // include
externalVar[findStr]; // include

