var _Array$from = require("core-js/library/fn/array/from.js");

var _Array$isArray = require("core-js/library/fn/array/is-array.js");

var _Array$of = require("core-js/library/fn/array/of.js");

var _Date$now = require("core-js/library/fn/date/now.js");

var _JSON$stringify = require("core-js/library/fn/json/stringify.js");

var _Number$EPSILON = require("core-js/library/fn/number/epsilon.js");

var _Number$MAX_SAFE_INTEGER = require("core-js/library/fn/number/max-safe-integer.js");

var _Number$MIN_SAFE_INTEGER = require("core-js/library/fn/number/min-safe-integer.js");

var _Number$isFinite = require("core-js/library/fn/number/is-finite.js");

var _Number$isInteger = require("core-js/library/fn/number/is-integer.js");

var _Number$isNaN = require("core-js/library/fn/number/is-nan.js");

var _Number$isSafeInteger = require("core-js/library/fn/number/is-safe-integer.js");

var _Number$parseFloat = require("core-js/library/fn/number/parse-float.js");

var _Number$parseInt = require("core-js/library/fn/number/parse-int.js");

var _Object$assign = require("core-js/library/fn/object/assign.js");

var _Object$create = require("core-js/library/fn/object/create.js");

var _Object$defineProperties = require("core-js/library/fn/object/define-properties.js");

var _Object$defineProperty = require("core-js/library/fn/object/define-property.js");

var _Object$entries = require("core-js/library/fn/object/entries.js");

var _Object$freeze = require("core-js/library/fn/object/freeze.js");

var _Object$getOwnPropertyDescriptor = require("core-js/library/fn/object/get-own-property-descriptor.js");

var _Object$getOwnPropertyDescriptors = require("core-js/library/fn/object/get-own-property-descriptors.js");

var _Object$getOwnPropertyNames = require("core-js/library/fn/object/get-own-property-names.js");

var _Object$getOwnPropertySymbols = require("core-js/library/fn/object/get-own-property-symbols.js");

var _Object$getPrototypeOf = require("core-js/library/fn/object/get-prototype-of.js");

var _Object$isExtensible = require("core-js/library/fn/object/is-extensible.js");

var _Object$isFrozen = require("core-js/library/fn/object/is-frozen.js");

var _Object$isSealed = require("core-js/library/fn/object/is-sealed.js");

var _Object$is = require("core-js/library/fn/object/is.js");

var _Object$keys = require("core-js/library/fn/object/keys.js");

var _Object$preventExtensions = require("core-js/library/fn/object/prevent-extensions.js");

var _Object$seal = require("core-js/library/fn/object/seal.js");

var _Object$setPrototypeOf = require("core-js/library/fn/object/set-prototype-of.js");

var _Object$values = require("core-js/library/fn/object/values.js");

var _Reflect$apply = require("core-js/library/fn/reflect/apply.js");

var _Reflect$construct = require("core-js/library/fn/reflect/construct.js");

var _Reflect$defineProperty = require("core-js/library/fn/reflect/define-property.js");

var _Reflect$deleteProperty = require("core-js/library/fn/reflect/delete-property.js");

var _Reflect$getOwnPropertyDescriptor = require("core-js/library/fn/reflect/get-own-property-descriptor.js");

var _Reflect$getPrototypeOf = require("core-js/library/fn/reflect/get-prototype-of.js");

var _Reflect$get = require("core-js/library/fn/reflect/get.js");

var _Reflect$has = require("core-js/library/fn/reflect/has.js");

var _Reflect$isExtensible = require("core-js/library/fn/reflect/is-extensible.js");

var _Reflect$ownKeys = require("core-js/library/fn/reflect/own-keys.js");

var _Reflect$preventExtensions = require("core-js/library/fn/reflect/prevent-extensions.js");

var _Reflect$set = require("core-js/library/fn/reflect/set.js");

var _Reflect$setPrototypeOf = require("core-js/library/fn/reflect/set-prototype-of.js");

var _String$fromCodePoint = require("core-js/library/fn/string/from-code-point.js");

var _String$raw = require("core-js/library/fn/string/raw.js");

var _Symbol = require("core-js/library/fn/symbol.js");

var _Symbol$for = require("core-js/library/fn/symbol/for.js");

var _Symbol$hasInstance = require("core-js/library/fn/symbol/has-instance.js");

var _Symbol$isConcatSpreadable = require("core-js/library/fn/symbol/is-concat-spreadable.js");

var _Symbol$iterator = require("core-js/library/fn/symbol/iterator.js");

var _Symbol$keyFor = require("core-js/library/fn/symbol/key-for.js");

var _Symbol$match = require("core-js/library/fn/symbol/match.js");

var _Symbol$replace = require("core-js/library/fn/symbol/replace.js");

var _Symbol$search = require("core-js/library/fn/symbol/search.js");

var _Symbol$species = require("core-js/library/fn/symbol/species.js");

var _Symbol$split = require("core-js/library/fn/symbol/split.js");

var _Symbol$toPrimitive = require("core-js/library/fn/symbol/to-primitive.js");

var _Symbol$toStringTag = require("core-js/library/fn/symbol/to-string-tag.js");

var _Symbol$unscopables = require("core-js/library/fn/symbol/unscopables.js");

_Array$from;
_Array$isArray;
_Array$of;
_Date$now;
_JSON$stringify;
_Number$EPSILON;
_Number$MAX_SAFE_INTEGER;
_Number$MIN_SAFE_INTEGER;
Number.fromString;
_Number$isFinite;
_Number$isInteger;
_Number$isNaN;
_Number$isSafeInteger;
_Number$parseFloat;
_Number$parseInt;
_Object$assign;
_Object$create;
_Object$defineProperties;
_Object$defineProperty;
_Object$entries;
_Object$freeze;
Object.fromEntries;
_Object$getOwnPropertyDescriptor;
_Object$getOwnPropertyDescriptors;
_Object$getOwnPropertyNames;
_Object$getOwnPropertySymbols;
_Object$getPrototypeOf;
_Object$isExtensible;
_Object$isFrozen;
_Object$isSealed;
_Object$is;
_Object$keys;
_Object$preventExtensions;
_Object$seal;
_Object$setPrototypeOf;
_Object$values;
_Reflect$apply;
_Reflect$construct;
Reflect.defineMetadata;
_Reflect$defineProperty;
Reflect.deleteMetadata;
_Reflect$deleteProperty;
Reflect.getMetadata;
Reflect.getMetadataKeys;
Reflect.getOwnMetadata;
Reflect.getOwnMetadataKeys;
_Reflect$getOwnPropertyDescriptor;
_Reflect$getPrototypeOf;
_Reflect$get;
_Reflect$has;
Reflect.hasMetadata;
Reflect.hasOwnMetadata;
_Reflect$isExtensible;
Reflect.metadata;
_Reflect$ownKeys;
_Reflect$preventExtensions;
_Reflect$set;
_Reflect$setPrototypeOf;
_String$fromCodePoint;
_String$raw;
_Symbol.asyncIterator;
_Symbol.dispose;
_Symbol$for;
_Symbol$hasInstance;
_Symbol$isConcatSpreadable;
_Symbol$iterator;
_Symbol$keyFor;
_Symbol$match;
_Symbol.observable;
_Symbol.patternMatch;
_Symbol$replace;
_Symbol$search;
_Symbol$species;
_Symbol$split;
_Symbol$toPrimitive;
_Symbol$toStringTag;
_Symbol$unscopables;
Foo.bar;
Array.something;
Date.something;
JSON.parse;
Math.pow;
_Symbol.something;
