import "core-js/modules/es.function.bind.js";
import "core-js/modules/es.object.entries.js";
import "core-js/modules/es.date.to-string.js";
import "core-js/modules/es.object.to-string.js";
import "core-js/modules/es.regexp.to-string.js";
import "core-js/modules/es.string.iterator.js";
import "core-js/modules/es.array.iterator.js";
import "core-js/modules/web.dom-collections.iterator.js";
import "core-js/modules/es.regexp.exec.js";
import "core-js/modules/es.string.trim.js";
import "core-js/modules/es.array.filter.js";
import "core-js/modules/es.string.includes.js";
import "core-js/modules/es.array.from.js";
import "core-js/modules/es.array.of.js";
import "core-js/modules/es.array.for-each.js";
import "core-js/modules/web.dom-collections.for-each.js";
var bind, toString;
var {
  bind
} = Function;
var {
  entries
} = Object;
({
  toString
} = obj);
const [{
  exec
}] = something;
const {
  'trim': foo
} = '1';
const {
  foo: {
    filter
  }
} = {
  foo: []
};
const {
  includes
} = '';
var bar = Array;
const {
  from
} = bar;
const {
  ['o' + 'f']: fuz
} = Array;
let forEach = 'sort';
({
  forEach
} = zzz);
