import "object.entries/auto";
import "string.prototype.trim/auto";
import "array.prototype.filter/auto";
import "array-includes/auto";
import "string.prototype.includes/auto";
import "array.from/auto";
import "array.of/auto";
var bind, toString;
var {
  bind
} = Function;
var {
  entries
} = Object;
({
  toString
} = obj);
const [{
  exec
}] = something;
const {
  'trim': foo
} = '1';
const {
  foo: {
    filter
  }
} = {
  foo: []
};
const {
  includes
} = '';
var bar = Array;
const {
  from
} = bar;
const {
  ['o' + 'f']: fuz
} = Array;
let forEach = 'sort';
({
  forEach
} = zzz);
