import "object.entries/auto";
import "array.from/auto";
import "array-includes/auto";
import "string.prototype.includes/auto";
!function (foo, {
  entries
}) {}({}, Object);
new function (foo, {
  from
}) {}({}, Array);

(({
  includes
}) => {})('42');
